@@ -10,14 +10,20 @@
 ## Assemble plots to make UpSet plot
 Make_base_plot <- function(Main_bar_plot, Matrix_plot, Size_plot, labels, hratios, att_x, att_y,
                            Set_data, exp, position, start_col, att_color, QueryData,
-                           attribute_plots, legend, query_legend, boxplot, names, set_metadata){
+                           attribute_plots, legend, query_legend, boxplot, names, set_metadata,
+                           set_metadata_plots){
   
   end_col <- ((start_col + as.integer(length(labels))) - 1)
   Set_data <- Set_data[which(rowSums(Set_data[ ,start_col:end_col]) != 0), ]
   Main_bar_plot$widths <- Matrix_plot$widths
   Matrix_plot$heights <- Size_plot$heights
   if(is.null(set_metadata) ==F){
-    set_metadata$heights <- Size_plot$heights
+    ncols <- 0
+    for(i in 1:length(set_metadata_plots)){
+      ncols <- ncols + set_metadata$plots[[i]]$assign
+      set_metadata_plots[[i]]$heights <- Size_plot$heights
+    }
+    set_metadata$ncols <- ncols
   }
   if(is.null(legend)==F){
     legend$widths <- Matrix_plot$widths
@@ -30,10 +36,10 @@ Make_base_plot <- function(Main_bar_plot, Matrix_plot, Size_plot, labels, hratio
   
   size_plot_height <- (((hratios[1])+0.01)*100)
   if((hratios[1] > 0.7 || hratios[1] < 0.3) ||
-       (hratios[2] > 0.7 || hratios[2] < 0.3)) warning("Plot might be out of range if ratio > 0.7 or < 0.3")
+     (hratios[2] > 0.7 || hratios[2] < 0.3)) warning("Plot might be out of range if ratio > 0.7 or < 0.3")
   if(is.null(attribute_plots) == T && is.null(boxplot) == T){
     NoAttBasePlot(legend, size_plot_height, Main_bar_plot, Matrix_plot, hratios, Size_plot, query_legend,
-                  set_metadata)
+                  set_metadata, set_metadata_plots)
   }
   else if(is.null(attribute_plots) == F && is.null(boxplot) == T){
     plots <- GenerateCustomPlots(attribute_plots, Set_data, QueryData, att_color, att_x, att_y, names)
@@ -41,11 +47,11 @@ Make_base_plot <- function(Main_bar_plot, Matrix_plot, Size_plot, labels, hratio
     #        attribute_plots$plots[[i]]$plot <- plots[[i]]
     #      }
     BaseCustomPlot(attribute_plots, plots, position, size_plot_height, Main_bar_plot, Matrix_plot, Size_plot,
-                   hratios, legend, query_legend, set_metadata)
+                   hratios, legend, query_legend, set_metadata, set_metadata_plots)
   }
   else if(is.null(boxplot)==F && is.null(attribute_plots) == T){
     BaseBoxPlot(boxplot, position, size_plot_height, Main_bar_plot, Matrix_plot, Size_plot,
-                hratios, set_metadata)
+                hratios, set_metadata, set_metadata_plots)
   }
 }
 
@@ -56,7 +62,7 @@ vplayout <- function(x,y){
 
 ## Generates UpSet plot with boxplots representing distributions of attributes
 BaseBoxPlot <- function(box_plot, position, size_plot_height, Main_bar_plot, Matrix_plot,
-                        Size_plot, hratios, set_metadata){
+                        Size_plot, hratios, set_metadata, set_metadata_plots){
   if(length(box_plot) > 2){
     return(warning("UpSet can only show 2 box plots at a time"))
   }
@@ -95,11 +101,11 @@ BaseBoxPlot <- function(box_plot, position, size_plot_height, Main_bar_plot, Mat
     size_bar_left <- 1
   }
   else if(is.null(set_metadata) == F){
-    matrix_and_mainbar_right <- 120
-    matrix_and_mainbar_left <- 41
-    size_bar_right <- 40
-    size_bar_left <- 21
-    metadata_right <- 20
+    matrix_and_mainbar_right <- set_metadata$ncols + 100
+    matrix_and_mainbar_left <- set_metadata$ncols + 21
+    size_bar_right <- set_metadata$ncols + 20
+    size_bar_left <- set_metadata$ncols + 1
+    metadata_right <- set_metadata$ncols
     metadata_left <- 1
   }
   grid.newpage()
@@ -118,10 +124,21 @@ BaseBoxPlot <- function(box_plot, position, size_plot_height, Main_bar_plot, Mat
   grid.draw(arrangeGrob(Size_plot))
   popViewport()
   if(is.null(set_metadata) == F){
-    vp = vplayout(size_plot_height:matrix_bottom, metadata_left:metadata_right)
-    pushViewport(vp)
-    grid.draw(arrangeGrob(set_metadata))
-    popViewport()
+    for(i in 1:length(set_metadata_plots)){
+      if(i != 1){
+        metadata_left <- 1+metadata_right
+        metadata_right <- metadata_right + set_metadata$plots[[i]]$assign
+      }
+      else{
+        metadata_left <- 1
+        metadata_right <- set_metadata$plots[[i]]$assign
+      }
+      
+      vp = vplayout(size_plot_height:matrix_bottom, metadata_left:metadata_right)
+      pushViewport(vp)
+      grid.draw(arrangeGrob(set_metadata_plots[[i]]))
+      popViewport()
+    }
   }
   vp = vplayout(att_top:att_bottom, matrix_and_mainbar_left:matrix_and_mainbar_right)
   pushViewport(vp)
@@ -137,7 +154,7 @@ BaseBoxPlot <- function(box_plot, position, size_plot_height, Main_bar_plot, Mat
 
 ## Generates UpSet plot when no attributes are selected to be plotted
 NoAttBasePlot <- function(legend, size_plot_height, Main_bar_plot, Matrix_plot, hratios,
-                          Size_plot, query_legend, set_metadata){
+                          Size_plot, query_legend, set_metadata, set_metadata_plots){
   top <- 1
   bottom <- 100
   if((is.null(legend) == F) && (query_legend != tolower("none"))){
@@ -160,11 +177,11 @@ NoAttBasePlot <- function(legend, size_plot_height, Main_bar_plot, Matrix_plot,
     size_bar_left <- 1
   }
   else if(is.null(set_metadata) == F){
-    matrix_and_mainbar_right <- 120
-    matrix_and_mainbar_left <- 41
-    size_bar_right <- 40
-    size_bar_left <- 21
-    metadata_right <- 20
+    matrix_and_mainbar_right <- set_metadata$ncols + 100
+    matrix_and_mainbar_left <- set_metadata$ncols + 21
+    size_bar_right <- set_metadata$ncols + 20
+    size_bar_left <- set_metadata$ncols + 1
+    metadata_right <- set_metadata$ncols
     metadata_left <- 1
   }
   grid.newpage()
@@ -188,10 +205,21 @@ NoAttBasePlot <- function(legend, size_plot_height, Main_bar_plot, Matrix_plot,
   grid.draw(arrangeGrob(Size_plot))
   popViewport()
   if(is.null(set_metadata) == F){
-    vp = vplayout(size_plot_height:bottom, metadata_left:metadata_right)
-    pushViewport(vp)
-    grid.draw(arrangeGrob(set_metadata))
-    popViewport()
+    for(i in 1:length(set_metadata_plots)){
+      if(i != 1){
+        metadata_left <- 1+metadata_right
+        metadata_right <- metadata_right + set_metadata$plots[[i]]$assign
+      }
+      else{
+        metadata_left <- 1
+        metadata_right <- set_metadata$plots[[i]]$assign
+      }
+      
+      vp = vplayout(size_plot_height:bottom, metadata_left:metadata_right)
+      pushViewport(vp)
+      grid.draw(arrangeGrob(set_metadata_plots[[i]]))
+      popViewport()
+    }
   }
   if((is.null(legend) == F) && (query_legend != tolower("none"))){
     vp = vplayout(legend_top:legend_bottom, matrix_and_mainbar_left:matrix_and_mainbar_right)
@@ -203,7 +231,7 @@ NoAttBasePlot <- function(legend, size_plot_height, Main_bar_plot, Matrix_plot,
 
 ## Function that plots out the list of plots generated from custom plot input
 BaseCustomPlot <- function(attribute_plots, plots, position, size_plot_height, Main_bar_plot, Matrix_plot,
-                           Size_plot, hratios, legend, q_legend, set_metadata){
+                           Size_plot, hratios, legend, q_legend, set_metadata, set_metadata_plots){
   bar_top <- 1
   matrix_bottom <- 100
   custom_top <- 101
@@ -216,11 +244,11 @@ BaseCustomPlot <- function(attribute_plots, plots, position, size_plot_height, M
     size_bar_left <- 1
   }
   else if(is.null(set_metadata) == F){
-    matrix_and_mainbar_right <- 120
-    matrix_and_mainbar_left <- 41
-    size_bar_right <- 40
-    size_bar_left <- 21
-    metadata_right <- 20
+    matrix_and_mainbar_right <- set_metadata$ncols + 100
+    matrix_and_mainbar_left <- set_metadata$ncols + 21
+    size_bar_right <- set_metadata$ncols + 20
+    size_bar_left <- set_metadata$ncols + 1
+    metadata_right <- set_metadata$ncols
     metadata_left <- 1
   }
   
@@ -236,10 +264,21 @@ BaseCustomPlot <- function(attribute_plots, plots, position, size_plot_height, M
   grid.draw(arrangeGrob(Size_plot))
   popViewport()
   if(is.null(set_metadata) == F){
-    vp = vplayout(size_plot_height:matrix_bottom, metadata_left:metadata_right)
-    pushViewport(vp)
-    grid.draw(arrangeGrob(set_metadata))
-    popViewport()
+    for(i in 1:length(set_metadata_plots)){
+      if(i != 1){
+        metadata_left <- 1+metadata_right
+        metadata_right <- metadata_right + set_metadata$plots[[i]]$assign
+      }
+      else{
+        metadata_left <- 1
+        metadata_right <- set_metadata$plots[[i]]$assign
+      }
+      
+      vp = vplayout(size_plot_height:matrix_bottom, metadata_left:metadata_right)
+      pushViewport(vp)
+      grid.draw(arrangeGrob(set_metadata_plots[[i]]))
+      popViewport()
+    }
   }
   if((is.null(legend) == F) && (q_legend != tolower("none"))){
     vp = vplayout(custom_top:(custom_bottom - 5), 1:matrix_and_mainbar_right)
@@ -262,4 +301,4 @@ BaseCustomPlot <- function(attribute_plots, plots, position, size_plot_height, M
 
 # printCustom <- function(attribute_plots){
 #   print(attribute_plots$plot, vp = vplayout(attribute_plots$rows, attribute_plots$cols), newpage = F)
-# }
+# }
\ No newline at end of file
